@@ -4,7 +4,7 @@ test_that("simple denominator", {
   expect_equal(nom_denom(3), "third")
   expect_equal(nom_denom(12), "twelfth")
   expect_equal(nom_denom(21), "twenty-first")
-  expect_equal(nom_denom(100000000), "one-hundred-millionth")
+  expect_equal(nom_denom(100000000), "hundred-millionth")
 })
 
 test_that("plural denominator", {
@@ -13,16 +13,16 @@ test_that("plural denominator", {
   expect_equal(nom_denom(3, 2), "thirds")
   expect_equal(nom_denom(12, 2), "twelfths")
   expect_equal(nom_denom(21, 2), "twenty-firsts")
-  expect_equal(nom_denom(100000000, 2), "one-hundred-millionths")
+  expect_equal(nom_denom(100000000, 2), "hundred-millionths")
 })
 
 test_that("denominator vector", {
   expect_equal(
-    nom_denom(c(1, 2, 100000000)), c("whole", "half", "one-hundred-millionth")
+    nom_denom(c(1, 2, 100000000)), c("whole", "half", "hundred-millionth")
   )
   expect_equal(
     nom_denom(c(1, 2, 100000000), 1:3),
-    c("whole", "halves", "one-hundred-millionths")
+    c("whole", "halves", "hundred-millionths")
   )
 })
 
